<?php

namespace FiloBlu\Eva\Setup;

use Magento\Framework\Setup\UpgradeDataInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\DB\Ddl\Table;


class UpgradeData implements UpgradeDataInterface {


    private $_contentTypeFactory;
    private $_customFieldsetFactory;
    private $_setupDataProvider;
    private $_blockFactory;


    public function __construct(
        \Blackbird\ContentManager\Api\Data\ContentTypeInterfaceFactory $contentTypeInterfaceFactory,
        \Blackbird\ContentManager\Api\Data\ContentType\CustomFieldsetInterfaceFactory $customFieldInterfaceFactory,
        \FiloBlu\Eva\Block\SetupDataProvider $setupDataProvider,
        \Magento\Cms\Model\BlockFactory $blockFactory
    ) {
        $this->_contentTypeFactory = $contentTypeInterfaceFactory;
        $this->_customFieldsetFactory = $customFieldInterfaceFactory;
        $this->_setupDataProvider = $setupDataProvider;
        $this->_blockFactory = $blockFactory;
    }

    public function upgrade( ModuleDataSetupInterface $setup, ModuleContextInterface $context ) {

        if ( version_compare( $context->getVersion(), '1.0.1', '<' ) ) {
            $this->_installDefaultBlocks();
            $this->_installPrivacyBlocks();
            $this->_installMenu($setup);
        }

    }

    public function _installMenu($setup)
    {

        $menuTable = 'blackbird_menumanager_menu';
        $connection = $setup->getConnection();

        if ($connection->isTableExists($menuTable) == true) {
            $menuData = [
                'title' => 'main-menu',
                'identifier' => 'main-menu'
            ];

            $connection->insert(
                $menuTable, $menuData
            );
        }

        $installedMenuId = $connection->lastInsertId('blackbird_menumanager_menu');
        $menuNodeTable = 'blackbird_menumanager_node';


        if ($connection->isTableExists($menuNodeTable) == true && $connection->fetchOne("SELECT * FROM $menuNodeTable") == false) {
            $menuNodeData[] = ['node_id' => 1, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => null, 'position' => 0, 'level' => 0, 'title' => 'VOCE MENU 01'];
            $menuNodeData[] = ['node_id' => 2, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 1, 'position' => 0, 'level' => 1, 'title' => 'Categoria 01'];
            $menuNodeData[] = ['node_id' => 3, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => null, 'position' => 1, 'level' => 0, 'title' => 'VOCE MENU 02'];
            $menuNodeData[] = ['node_id' => 4, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 1, 'position' => 3, 'level' => 1, 'title' => 'Categoria 04'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 2, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 2, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 2, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 2, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 2, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 4, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 4, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 4, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 4, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 4, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 15, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => null, 'position' => 2, 'level' => 0, 'title' => 'VOCE MENU 03'];
            $menuNodeData[] = ['node_id' => 16, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 1, 'position' => 2, 'level' => 1, 'title' => 'Categoria 03'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 16, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 16, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 16, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 16, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 16, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 22, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => null, 'position' => 3, 'level' => 0, 'title' => 'VOCE MENU 04'];
            $menuNodeData[] = ['node_id' => 23, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 1, 'position' => 1, 'level' => 1, 'title' => 'Categoria 02'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 23, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 23, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 23, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 23, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 23, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 29, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 3, 'position' => 0, 'level' => 1, 'title' => 'Categoria 01'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 29, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 29, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 29, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 29, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 34, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 3, 'position' => 1, 'level' => 1, 'title' => 'Categoria 02'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 34, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 34, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 34, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 34, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 39, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 3, 'position' => 2, 'level' => 1, 'title' => 'Categoria 03'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 39, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 39, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 39, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 39, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 45, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 3, 'position' => 3, 'level' => 1, 'title' => 'Categoria 04'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 45, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 45, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 45, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 45, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 29, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 34, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 39, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 45, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 54, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 15, 'position' => 0, 'level' => 1, 'title' => 'Categoria 01'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 54, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 54, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 54, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 54, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 59, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 15, 'position' => 1, 'level' => 1, 'title' => 'Categoria 02'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 59, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 59, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 59, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 59, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 64, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 15, 'position' => 2, 'level' => 1, 'title' => 'Categoria 03'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 64, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 64, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 64, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 64, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 69, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 15, 'position' => 3, 'level' => 1, 'title' => 'Categoria 04'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 69, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 69, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 69, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 69, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 54, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 59, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 64, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 69, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['node_id' => 78, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 22, 'position' => 0, 'level' => 1, 'title' => 'Categoria 01'];
            $menuNodeData[] = ['node_id' => 79, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 22, 'position' => 1, 'level' => 1, 'title' => 'Categoria 02'];
            $menuNodeData[] = ['node_id' => 80, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 22, 'position' => 2, 'level' => 1, 'title' => 'Categoria 03'];
            $menuNodeData[] = ['node_id' => 81, 'menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 22, 'position' => 3, 'level' => 1, 'title' => 'Categoria 04'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 78, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 78, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 78, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 78, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 78, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 79, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 79, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 79, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 79, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 79, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 80, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 80, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 80, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 80, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 80, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 81, 'position' => 0, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 81, 'position' => 1, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 81, 'position' => 2, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 81, 'position' => 3, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];
            $menuNodeData[] = ['menu_id' => $installedMenuId, 'type' => 'group', 'parent_id' => 81, 'position' => 4, 'level' => 2, 'title' => 'Lorem ipsu dolor sit amet'];

            $connection = $setup->getConnection();
            foreach ($menuNodeData as $item) {
                $connection->insert($menuNodeTable, $item);
            }
        }

        $menuStoreTable = 'blackbird_menumanager_store';

        if ($connection->isTableExists($menuStoreTable) == true) {
            $connection = $setup->getConnection();
            $connection->insert(
                $menuStoreTable, [
                    'menu_id' => $installedMenuId,
                    'store_id' => 0
                ]
            );
        }

    }

    public function _installDefaultBlocks() {
        $privacyBlock = $this->_setupDataProvider->getDefaultBlocks();
        foreach ($privacyBlock as $block) {
            $this->_blockFactory->create()->setData($block)->save();
        }
    }

    public function _installPrivacyBlocks() {
        $privacyBlock = $this->_setupDataProvider->getPrivacyBlocks();
        foreach ($privacyBlock as $block) {
            $this->_blockFactory->create()->setData($block)->save();
        }
    }



}